..
.. Copyright John Reid 2012
..
.. This is a reStructuredText document. If you are reading this in text format, it can be 
.. converted into a more readable format by using Docutils_ tools such as rst2html.
..

.. _Docutils: http://docutils.sourceforge.net/docs/user/tools.html


Cookbook package
================

.. automodule:: cookbook
   :members:




Bidirectional map
-----------------
.. automodule:: cookbook.bidirectional_map
   :members:


Bunch
-----
.. automodule:: cookbook.bunch
   :members:


Cache decorator
---------------
.. automodule:: cookbook.cache_decorator
   :members:


Console
-------
.. automodule:: cookbook.console
   :members:


Const
-----
.. automodule:: cookbook.const


Decorate
--------
.. automodule:: cookbook.decorate
   :members:


Dicts
-----
.. automodule:: cookbook.dicts
   :members:


Enum
----
.. automodule:: cookbook.enum
   :members:


Equivalence
-----------
.. automodule:: cookbook.equivalence
   :members:


Function as task
----------------
.. automodule:: cookbook.function_as_task
   :members:


Group by
--------
.. automodule:: cookbook.groupby
   :members:


Interval
--------
.. automodule:: cookbook.interval
   :members:


LRU cache
---------
.. automodule:: cookbook.lru_cache
   :members:


Named tuple
-----------
.. automodule:: cookbook.named_tuple
   :members:


Output context
--------------
.. automodule:: cookbook.output_context
   :members:


Permutation
-----------
.. automodule:: cookbook.permutation
   :members:


Persisted cache
---------------
.. automodule:: cookbook.persisted_cache
   :members:


Pre/post conditions
-------------------
.. automodule:: cookbook.pre_post_conditions
   :members:


Progress
--------
.. automodule:: cookbook.progress
   :members:


Pylab utilities
---------------
.. automodule:: cookbook.pylab_utils
   :members:


Pytables utilities
------------------
.. automodule:: cookbook.pytables_utils
   :members:


Red-black interval tree
-----------------------
.. automodule:: cookbook.rb_interval_tree
   :members:


Red-black tree
--------------
.. automodule:: cookbook.rbtree
   :members:


Reverse dict
------------
.. automodule:: cookbook.reverse_dict
   :members:


Script utilities
----------------
.. automodule:: cookbook.script_basics
   :members:


Logging utilities
-----------------
.. automodule:: cookbook.simple_logging
   :members:


Timer
-----
.. automodule:: cookbook.timer
   :members:


Venn
----
.. automodule:: cookbook.venn
   :members:


Workflow
--------
.. automodule:: cookbook.workflow
   :members:

